import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class PollPage extends StatefulWidget {
  @override
  _PollPageState createState() => _PollPageState();
}

class _PollPageState extends State<PollPage> {
  bool isOption3 = false;
  bool isOption4 = false;
  bool isValid = false;
  final questionController = TextEditingController();
  final option1Controller = TextEditingController();
  final option2Controller = TextEditingController();
  final option3Controller = TextEditingController();
  final option4Controller = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Scaffold(
        appBar: AppBar(
          actions: <Widget>[
            _buildDoneButton(),
          ],
          leading: IconButton(
            onPressed: () {
              Navigator.pop(context);
            },
            icon: Icon(Icons.arrow_back, color: Colors.white),
          ),
          title: Text('Create a poll'),
          backgroundColor: Color(0xFF083356),
        ),
        body: _buildContent(),
      ),
    );
  }

  _buildContent() {
    return Padding(
      padding: EdgeInsets.all(ScreenUtil().setHeight(20)),
      child: ListView(
        children: [
          _buildField(
            labelText: 'Your question *',
            hintText: 'e.g., How do you commute to work?',
            maxLength: 140,
            isQuestion: true,
            controller: questionController,
          ),
          _buildField(
            labelText: 'Option 1 *',
            hintText: 'e.g., Public Transport',
            maxLength: 30,
            isQuestion: false,
            controller: option1Controller,
          ),
          _buildField(
            labelText: 'Option 2 *',
            hintText: 'e.g., Walking',
            maxLength: 30,
            isQuestion: false,
            controller: option2Controller,
          ),
          isOption3
              ? Column(
                  children: [
                    _buildRemoveButton(),
                    _buildField(
                      labelText: 'Option 3',
                      hintText: 'e.g., Carpool',
                      maxLength: 30,
                      isQuestion: false,
                      controller: option3Controller,
                    )
                  ],
                )
              : Text(""),
          isOption4
              ? Column(
                  children: [
                    _buildRemoveButton(),
                    _buildField(
                      labelText: 'Option 4',
                      hintText: 'e.g., Drive myself',
                      maxLength: 30,
                      isQuestion: false,
                      controller: option4Controller,
                    )
                  ],
                )
              : Text(""),
          !isOption4 ? _buildAddOptionButton() : Text(""),
        ],
      ),
    );
  }

  _buildField(
      {@required String labelText,
      @required String hintText,
      @required int maxLength,
      @required bool isQuestion,
      @required TextEditingController controller}) {
    return TextField(
      onChanged: (text) {
        if (!questionController.text.isEmpty &&
            !option1Controller.text.isEmpty &&
            !option2Controller.text.isEmpty) {
          setState(
            () {
              isValid = true;
            },
          );
        }
      },
      controller: controller,
      maxLength: maxLength,
      maxLines: isQuestion == true ? null : 1,
      decoration: new InputDecoration(
        border: new OutlineInputBorder(
          borderSide: new BorderSide(
            color: Colors.teal,
          ),
        ),
        hintText: hintText,
        labelText: labelText,
      ),
    );
  }

  _buildAddOptionButton() {
    return Align(
      alignment: Alignment.bottomLeft,
      child: FlatButton(
        splashColor: Colors.lightBlue[100],
        shape: RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(25),
          side: BorderSide(color: Colors.blue),
        ),
        onPressed: () {
          setState(
            () {
              isOption3 == false ? isOption3 = true : isOption4 = true;
            },
          );
        },
        child: Text(
          '+ Add Option',
          style: TextStyle(
            color: Colors.blue,
          ),
        ),
      ),
    );
  }

  _buildRemoveButton() {
    return Align(
      alignment: Alignment.bottomRight,
      child: FlatButton(
        splashColor: Colors.lightBlue[100],
        onPressed: () {
          setState(() {
            this.isOption4 ? isOption4 = false : isOption3 = false;
          });
        },
        child: Text(
          "Remove",
          style: TextStyle(
            color: Colors.blue,
          ),
        ),
      ),
    );
  }

  _buildDoneButton() {
    return Align(
      alignment: Alignment.bottomLeft,
      child: FlatButton(
        onPressed: isValid
            ? () {
                Navigator.pop(context);
              }
            : null,
        child: Text(
          'Done',
          style: TextStyle(
            color: isValid ? Colors.white : Colors.grey,
          ),
        ),
      ),
    );
  }
}
